@@ -119,7 +119,7 @@ class MedusaReportGenerator:
 
         report = {
             'timestamp': timestamp,
-            'medusa_version': '0.11.0',
+            'medusa_version': '0.11.1',
             'scan_summary': {
                 'total_issues': len(findings),
                 'files_scanned': scan_results.get('files_scanned', 0),
@@ -137,7 +137,7 @@ class MedusaReportGenerator:
 
         # Save report
         output_path = output_path or self.output_dir / f"medusa-scan-{datetime.now().strftime('%Y%m%d-%H%M%S')}.json"
-        with open(output_path, 'w') as f:
+        with open(output_path, 'w', encoding='utf-8') as f:
             json.dump(report, f, indent=2)
 
         # Update history
@@ -163,7 +163,7 @@ class MedusaReportGenerator:
         # Keep last 100 scans
         history = history[-100:]
 
-        with open(self.history_file, 'w') as f:
+        with open(self.history_file, 'w', encoding='utf-8') as f:
             json.dump(history, f, indent=2)
 
     def generate_html_report(self, json_report_path: Path, output_path: Path = None) -> Path:
@@ -175,7 +175,7 @@ class MedusaReportGenerator:
 
         html = self._build_html_report(report)
 
-        with open(output_path, 'w') as f:
+        with open(output_path, 'w', encoding='utf-8') as f:
             f.write(html)
 
         return output_path
@@ -198,7 +198,7 @@ class MedusaReportGenerator:
         md = f"""# MEDUSA Security Scan Report
 
 **Generated:** {datetime.fromisoformat(timestamp).strftime('%B %d, %Y at %H:%M:%S')}
-**MEDUSA Version:** 0.11.0
+**MEDUSA Version:** 0.11.1
 
 ---
 
@@ -267,7 +267,7 @@ MEDUSA is a multi-language security scanner with 40+ specialized analyzers for a
 
 ---
 
-*Report generated by MEDUSA v0.11.0*
+*Report generated by MEDUSA v0.11.1*
 """
 
         # Save markdown report
@@ -829,7 +829,7 @@ MEDUSA is a multi-language security scanner with 40+ specialized analyzers for a
         </div>
 
         <div class="footer">
-            <div class="footer-title">MEDUSA v0.11.0</div>
+            <div class="footer-title">MEDUSA v0.11.1</div>
             <div>Multi-Language Security Scanner with 40+ Analyzers • Pantheon Security</div>
         </div>
     </div>
