@@ -85,9 +85,10 @@ class BaseInstaller(ABC):
         Returns:
             CompletedProcess result
         """
-        # Use shell=True on Windows for .cmd/.bat files
-        use_shell = platform.system() == 'Windows'
-        return subprocess.run(cmd, capture_output=True, text=True, check=check, shell=use_shell)
+        # On Windows, we don't need shell=True when using explicit paths or when
+        # the package manager executables are in PATH (winget.exe, choco.exe work fine)
+        # shell=False is safer and works for all our use cases
+        return subprocess.run(cmd, capture_output=True, text=True, check=check, shell=False)
 
 
 class EcosystemDetector:
