@@ -348,13 +348,18 @@ class WindowsCustomInstaller:
 
     # Tools that have custom .bat installers
     SUPPORTED_TOOLS = {
-        'phpstan': 'install-phpstan.bat',
-        'ktlint': 'install-ktlint.bat',
-        'checkstyle': 'install-checkstyle.bat',
-        'clj-kondo': 'install-clj-kondo.bat',
-        'scalastyle': 'install-scalastyle.bat',
-        'codenarc': 'install-codenarc.bat',
-        'checkmake': 'install-checkmake.bat',
+        'phpstan': 'install-phpstan.cmd',
+        'ktlint': 'install-ktlint.cmd',
+        'checkstyle': 'install-checkstyle.cmd',
+        'clj-kondo': 'install-clj-kondo.cmd',
+        'scalastyle': 'install-scalastyle.cmd',
+        'codenarc': 'install-codenarc.cmd',
+        'checkmake': 'install-checkmake.cmd',
+    }
+
+    # Tools available via chocolatey (try this first to avoid antivirus false positives)
+    CHOCOLATEY_PACKAGES = {
+        'clj-kondo': 'clj-kondo',
     }
 
     @staticmethod
@@ -368,15 +373,42 @@ class WindowsCustomInstaller:
         if not WindowsCustomInstaller.can_install(tool):
             return False
 
+        # Try chocolatey first (avoids antivirus false positives)
+        if tool in WindowsCustomInstaller.CHOCOLATEY_PACKAGES:
+            if debug:
+                print(f"[DEBUG] Attempting chocolatey install for {tool}...")
+
+            choco_path = shutil.which('choco')
+            if choco_path:
+                try:
+                    package_name = WindowsCustomInstaller.CHOCOLATEY_PACKAGES[tool]
+                    result = subprocess.run(
+                        [choco_path, 'install', package_name, '-y'],
+                        capture_output=True,
+                        text=True,
+                        timeout=300
+                    )
+                    if result.returncode == 0:
+                        if debug:
+                            print(f"[DEBUG] Successfully installed {tool} via chocolatey")
+                        return True
+                    else:
+                        if debug:
+                            print(f"[DEBUG] Chocolatey install failed, falling back to custom installer")
+                except Exception as e:
+                    if debug:
+                        print(f"[DEBUG] Chocolatey install error: {e}, falling back to custom installer")
+            else:
+                if debug:
+                    print(f"[DEBUG] Chocolatey not found, using custom installer")
+
         script_name = WindowsCustomInstaller.SUPPORTED_TOOLS[tool]
 
         # Get the script path (bundled with the package)
-        import pkg_resources
         try:
-            script_path = pkg_resources.resource_filename(
-                'medusa',
-                f'platform/installers/windows_scripts/{script_name}'
-            )
+            from importlib.resources import files
+            script_file = files('medusa').joinpath(f'platform/installers/windows_scripts/{script_name}')
+            script_path = str(script_file)
         except Exception as e:
             if debug:
                 print(f"[DEBUG] Failed to find installer script: {e}")
@@ -391,10 +423,11 @@ class WindowsCustomInstaller:
             print(f"[DEBUG] Running custom installer: {script_path}")
 
         try:
-            # Run the .bat script
+            # Run the .bat script via cmd.exe (safer than shell=True)
+            cmd_path = shutil.which('cmd') or 'C:\\Windows\\System32\\cmd.exe'
             result = subprocess.run(
-                [script_path],
-                shell=True,
+                [cmd_path, '/c', script_path],
+                shell=False,
                 check=False,
                 capture_output=not debug,  # Show output in debug mode
                 text=True
