@@ -26,7 +26,7 @@ class VimScanner(BaseScanner):
                 error_message="Vint not installed. Install with: pip install vim-vint")
 
         try:
-            result = subprocess.run(["vint", str(file_path)], capture_output=True, text=True, timeout=30)
+            result = subprocess.run([str(self.tool_path), str(file_path)], capture_output=True, text=True, timeout=30)
             issues = []
             for line in result.stdout.splitlines():
                 if ":" in line:
@@ -36,7 +36,9 @@ class VimScanner(BaseScanner):
                             issues.append(ScannerIssue(line=int(parts[1]), column=int(parts[2]) if parts[2].isdigit() else 0,
                                 severity=Severity.MEDIUM, code="vint", message=parts[3] if len(parts) > 3 else "Issue",
                                 rule_url="https://github.com/Vimjas/vint"))
-                        except: pass
+                        except (ValueError, IndexError):
+                            # Skip malformed vint output lines that can't be parsed
+                            pass
             return ScannerResult(file_path=file_path, scanner_name=self.name, issues=issues, scan_time=time.time() - start_time, success=True)
         except Exception as e:
             return ScannerResult(file_path=file_path, scanner_name=self.name, issues=[], scan_time=time.time() - start_time, success=False,
